@@ -2,7 +2,7 @@
 
 esslist=essential-packages-list
 mirror=http://ftp.debian.org/debian
-mirror=http://http.us.debian.org/debian
+mirror=http://ftp2.de.debian.org/debian
 dist=sid
 
 set -e
@@ -12,9 +12,17 @@ arches=`awk '($1 != "" && $1 !~ /^#/) {print $2}' /usr/share/dpkg/archtable \
 
 for arch in $arches
 do
-	if wget -O Packages-$arch.bz2 $mirror/dists/$dist/main/binary-$arch/Packages.bz2
+	if [ ! -f Packages-$arch ]
+	then
+		if wget -O Packages-$arch.bz2 $mirror/dists/$dist/main/binary-$arch/Packages.bz2
+		then
+			bunzip2 -f Packages-$arch.bz2
+		else
+			rm -f Packages-$arch
+		fi
+	fi
+	if [ -f Packages-$arch ]
 	then
-		bunzip2 -f Packages-$arch.bz2
 		printf > $esslist-$arch \
 			'This list was generated on %s for %s\n' \
 			"`LANG=C date`" "$arch"
@@ -29,5 +37,5 @@ do
 		echo "No essential packages list is available" \
 			"for $arch in $dist" > $esslist-$arch
 	fi
-	rm -f Packages-$arch
 done
+rm -f Packages-*
